==> nextcloud-30.0.10.tgz: nextcloud/apps/app_api/l10n/sv.js <==
OC.L10N.register(
    "app_api",
    {
    "External Apps management" : "Hantering av externa appar",
    "Cancel" : "Avbryt",
    "Delete" : "Radera",
    "Default" : "Förvald",
    "Edit" : "Redigera",
    "Name" : "Namn",
    "Host" : "Server",
    "Nextcloud URL" : "Nextcloud-URL",
    "Enabled" : "Aktiverad",
    "Display name" : "Visningsnamn",
    "Disabled" : "Inaktiverad",
    "Confirm" : "Bekräfta",
    "Save" : "Spara",
    "Register" : "Registrera",
    "External Apps" : "Externa appar",
    "{license}-licensed" : "{license}-licensierad",
    "Update to {version}" : "Uppdatera till {version}",
    "Remove" : "Ta bort",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen lägsta Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen minimum Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Denna applikation kan inte installeras då följande beroenden inte är uppfyllda: %s",
    "View in store" : "Visa i butik",
    "Visit website" : "Besök webbplats",
    "Report a bug" : "Rapportera ett problem",
    "User documentation" : "Användardokumentation",
    "Admin documentation" : "Administratörsdokumentation",
    "Developer documentation" : "Utvecklardokumentation",
    "This app is supported via your current Nextcloud subscription." : "Den här appen stöds via ditt nuvarande Nextcloud-abonnemang.",
    "Supported" : "Stöds",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Utvalda appar utvecklas av och inom gemenskapen. De erbjuder central funktionalitet och är redo för produktionsanvändning.",
    "Featured" : "Utvalda",
    "Update to {update}" : "Uppdatera till {update}",
    "Icon" : "Ikon",
    "Version" : "Version",
    "Daemon" : "Demon",
    "Level" : "Nivå",
    "Actions" : "Funktioner",
    "Results from other categories" : "Resultat från andra kategorier",
    "_Update_::_Update all_" : ["Uppdatera","Uppdatera alla"],
    "Type" : "Typ",
    "Display Name" : "Visningsnamn",
    "Network" : "Nätverk",
    "by {author}\n{license}" : "av {author}\n{license}",
    "Your apps" : "Dina appar",
    "Documentation" : "Dokumentation",
    "Details" : "Detaljer",
    "Changelog" : "Ändringslogg",
    "Active apps" : "Aktiva appar",
    "Disabled apps" : "Inaktiverade appar",
    "Updates" : "Uppdateringar",
    "Featured apps" : "Utvalda appar",
    "Supported apps" : "Appar som stöds",
    "Enable" : "Aktivera",
    "Disable" : "Inaktivera",
    "Allow untested app" : "Tillåt otestad app",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Den här appen är inte markerad som kompatibel med din Nextcloud-version. Om du fortsätter kan du fortfarande installera appen. Observera att appen kanske inte fungerar som förväntat.",
    "An error occurred during the request. Unable to proceed." : "Ett fel uppstod under begäran. Det gick inte att fortsätta.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Fel: Denna appen kan inte aktiveras eftersom den gör servern instabil"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3.tgz: nextcloud/apps/app_api/l10n/sv.js <==
OC.L10N.register(
    "app_api",
    {
    "External Apps management" : "Hantering av externa appar",
    "Cancel" : "Avbryt",
    "Delete" : "Radera",
    "Default" : "Förvald",
    "Edit" : "Redigera",
    "Name" : "Namn",
    "Host" : "Server",
    "Nextcloud URL" : "Nextcloud-URL",
    "Enabled" : "Aktiverad",
    "Remove" : "Ta bort",
    "From" : "Från",
    "To" : "Till",
    "Add" : "Lägg till",
    "Display name" : "Visningsnamn",
    "Disabled" : "Inaktiverad",
    "Confirm" : "Bekräfta",
    "Save" : "Spara",
    "Register" : "Registrera",
    "External Apps" : "Externa appar",
    "{license}-licensed" : "{license}-licensierad",
    "Update to {version}" : "Uppdatera till {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen lägsta Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen minimum Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Denna applikation kan inte installeras då följande beroenden inte är uppfyllda:",
    "View in store" : "Visa i butik",
    "Visit website" : "Besök webbplats",
    "Report a bug" : "Rapportera ett problem",
    "User documentation" : "Användardokumentation",
    "Admin documentation" : "Administratörsdokumentation",
    "Developer documentation" : "Utvecklardokumentation",
    "This app is supported via your current Nextcloud subscription." : "Den här appen stöds via ditt nuvarande Nextcloud-abonnemang.",
    "Supported" : "Stöds",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Utvalda appar utvecklas av och inom gemenskapen. De erbjuder central funktionalitet och är redo för produktionsanvändning.",
    "Featured" : "Utvalda",
    "Update to {update}" : "Uppdatera till {update}",
    "Icon" : "Ikon",
    "Version" : "Version",
    "Daemon" : "Demon",
    "Level" : "Nivå",
    "Actions" : "Funktioner",
    "Results from other categories" : "Resultat från andra kategorier",
    "_Update_::_Update all_" : ["Uppdatera","Uppdatera alla"],
    "Type" : "Typ",
    "Display Name" : "Visningsnamn",
    "Network" : "Nätverk",
    "by {author}\n{license}" : "av {author}\n{license}",
    "Your apps" : "Dina appar",
    "Documentation" : "Dokumentation",
    "Details" : "Detaljer",
    "Changelog" : "Ändringslogg",
    "Active apps" : "Aktiva appar",
    "Disabled apps" : "Inaktiverade appar",
    "Updates" : "Uppdateringar",
    "Featured apps" : "Utvalda appar",
    "Supported apps" : "Appar som stöds",
    "Enable" : "Aktivera",
    "Disable" : "Inaktivera",
    "Allow untested app" : "Tillåt otestad app",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Den här appen är inte markerad som kompatibel med din Nextcloud-version. Om du fortsätter kan du fortfarande installera appen. Observera att appen kanske inte fungerar som förväntat.",
    "An error occurred during the request. Unable to proceed." : "Ett fel uppstod under begäran. Det gick inte att fortsätta.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Fel: Denna appen kan inte aktiveras eftersom den gör servern instabil"
},
"nplurals=2; plural=(n != 1);");
